awstindex(y, qlambda = NULL, eta = 0.5, lkern = "Triangle", hinit = 1,
hincr = 1.25, hmax = 1000, graph = FALSE, symmetric = FALSE)y contains the observed values at location x.
In case of x=NULL (second parameter) y is assumed to be
observed on a one, two or three-dimensional grid. The dimension of
qlambda determines the scale parameter qlambda
for the stochastic penalty. The scaling parameter in the stochastic
penalty lambda is choosen as the qlambda-quantile
of eta is a memory parameter used to stabilize the procedure.
eta has to be between 0 and 1, with
eta=.5 being the default.lkern determines the location kernel to be used. Options
are "Uniform", "Triangle", "Quadratic",
"Cubic" and "Exponential". Default is "Triangle"hinit Initial bandwidth for the location penalty.
Appropriate value is choosen in case of hinit==NULLhincr hincr^(1/d), with d the
dimensionality of the design, is used as a factor to increase the
bandwidth between iterations. Defauts to hincr=1.2hmax Maximal bandwidth to be used. Determines the
number of iterations and is used as the stopping rule.graph if TRUE results are displayed after each
iteration step.symmetric==TRUE the stochastic penalty is
symmetrized, i.e. (sij + sji)/lambda is used instead of
sij/lambda. See references for details.yy an descending order statistics yn <- order(y)[n:1] is computed
and transformed observations x <- (1:(n-1))*yn[-n]/yn[-1] are defined. The transformed
observations are assumed to follow an inhomogenious exponential model. Adaptive Weights Smoothing,
i.e. function laws with parameter model="Exponential", is used
to construct an inhomogenious intensity estimate. The estimated tail index is the estimated
intensity in the left-most point, corresponding to the largest observation in the sample.
This estimate is similar to the Hill-estimate computed from the k largest observations
with k approximately equal to the sum of weights used for estimating the tail index
by AWS. See Section 8 in Polzehl and Spokoiny (2002) for details.aws, laws###
### Estimate the tail-index of a cauchy distribution
### absolute values can be used because of the symmetry of centered cauchy
###
set.seed(1)
n <- 500
x <- rcauchy(n)
tmp <- awstindex(abs(x),hmax=n)
tmp$tindex
###
### now show the segmentation generated by AWS
###
plot(tmp$intensity[1:250],type="l")Run the code above in your browser using DataLab