ICIcombined(y, hmax, hinc = 1.45, thresh = NULL, kern = "Gaussian", m = 0, sigma = NULL, nsector = 1, symmetric = FALSE, presmooth = FALSE)"array" containing the original (response) data
on a grid"character" kernel, can be any of
c("Gaussian","Uniform","Triangle","Epanechnicov","Biweight","Triweight").
Defaults to kern="Gaussian"."integer" vector of length length(dy)
determining the order of derivatives specified for the coordinate directios."logical" determines if sectors are symmetric with respect to the origin. ~~Describe symmetric here~~"logical" determines if bandwidths are smoothed
for more stable results.ICIsmoothICIsmooth, ICIsmooth-class, kernsm