Learn R Programming

aws (version 1.8-0)

awstestprop: Propagation condition for adaptive weights smoothing

Description

The function enables testing of the propagation condition in order to select appropriate values for the parameter lambda in function aws.

Usage

awstestprop(dy, hmax, theta = 1, family = "Gaussian", lkern = "Triangle", 
        aws = TRUE, memory = FALSE, shape = 2, ladjust = 1, seed = 1)

Arguments

dy
Dimension of grid used in 1D, 2D or 3D
hmax
Maximum bandwidth.
theta
Parameter determining the distribution in case of family %in% c("Poisson","Bernoulli")
family
family specifies the probability distribution. Default is family="Gaussian", also implemented are "Bernoulli", "Poisson", "Exponential", "Volatility" and "Variance". family="Volatility" specifies a Gaussian distri
lkern
character: location kernel, either "Triangle", "Plateau", "Quadratic", "Cubic" or "Gaussian"
aws
logical: if TRUE structural adaptation (AWS) is used.
memory
logical: if TRUE stagewise aggregation is used as an additional adaptation scheme.
shape
Allows to specify an additional shape parameter for certain family models. Currently only used for family="Variance", that is $\chi$-Square distributed observations with shape degrees of freedom.
ladjust
Factor to increase the default value of lambda
seed
Seed value for random generator.

Value

  • A list with components
  • hSequence of bandwidths used
  • zseq(0,30,.5), the quantiles exceedence probabilities refer to
  • probthe matrix of exceedence probabilities, columns corresponding to h
  • probnathe matrix of exceedence probabilities for corresponding nonadaptive estimates, columns corresponding to h
  • pofalphathe matrix of exceedence probabilities with respect to a grid of alpha for the direct propagation condition

Details

Estimates exceedence probabilities

Results for intermediate steps are provided as contour plots. For a good choice of lambda (ladjust) the contours up to probabilities of 1e-5 should be vertical.

References

Becker (2013)

See Also

aws