lambda in function aws.awstestprop(dy, hmax, theta = 1, family = "Gaussian", lkern = "Triangle",
aws = TRUE, memory = FALSE, shape = 2, homogeneous=TRUE, varadapt=FALSE, ladjust = 1, spmin=0.25, seed = 1,
minlevel=1e-6, maxz=25, diffz=.5, maxni=FALSE, verbose=FALSE)family %in% c("Poisson","Bernoulli")family specifies the probability distribution. Default is family="Gaussian", also implemented
are "Bernoulli", "Poisson", "Exponential", "Volatility", "Variance" and "NCchi". family="Volatility" specifies a Gaussishape degrees of freedom.homgeneous==FALSE and family==Gaussian then create heterogeneous variances according to
a chi-squared distribution with number of degrees of freedom given by spherevaradapt==TRUE use inverse of variance reduction instead of sum of weights in definition of statistical penalty.seq(0,30,.5), the quantiles exceedence probabilities refer tohhResults for intermediate steps are provided as contour plots. For a good choice of lambda
(ladjust) the contours up to probabilities of 1e-5 should be vertical.
aws